#!/etc/opt/openit/perl


my $filter_dir = "/var/opt/openit/etc/filtrator/";
my $ignore_case = "\t\t\t\tignore-case(Bool)=\"true\"{}\n";

push @filter_files, get_filters_to_update( $filter_dir, "^license-", "flex-log" );
push @filter_files, get_filters_to_update( $filter_dir, "^freeze-" );
push @filter_files, get_filters_to_update( $filter_dir, "^olap", "winapp" );
push @filter_files, get_filters_to_update( $filter_dir, "^licenseevents-" );

foreach my $filter ( @filter_files ) {
	my @lines = read_file( $filter );
	print "Reading $filter ...\n";

	my $line = 0;
	$line = locate_line( $line, "filter-defs", \@lines );
	$line = locate_line( $line, "Mapping.feature-rename", \@lines );
	
	if( $line != 0 ) {
		if( grep( /ignore-case/, @lines ) ) {
			$line = locate_line( $line, "ignore-case", \@lines );
			@lines[$line] =~ s/false/true/;
		}
		else {
			$line = locate_line( $line, "source", \@lines );
			@lines[$line] =~ s/\n/\n$ignore_case/;
		}

		save_file( $filter, 2144, @lines );
		print( "Successfully updated $filter\n" );
	}
}

exit( 0 );


# Subroutines -----------

sub get_filters_to_update {
    my ( $filter_dir, $include, $exclude ) = @_;

	opendir( DIR,$filter_dir );
	my @tmpfilters = readdir( DIR );
	closedir( DIR );
	
	@tmpfilters = grep { /\.conf$/ } @tmpfilters;
	@tmpfilters = grep { /$include/ } @tmpfilters;
	@tmpfilters = grep { !/old/ } @tmpfilters;
	
    if( defined( $exclude ) && $exclude ne "" ) {
		@tmpfilters = grep { !/$exclude/ } @tmpfilters;
    }
	
	my @filters;

	foreach my $file ( @tmpfilters ) {
        push @filters, "$filter_dir$file";
    }
    
	return @filters;
}

sub read_file {
	my ( $cfg ) = @_;
	open( IN, "$cfg" ) || die "ERROR: Unable to read cfg '$cfg'!\n";
	my @lines = <IN>;
	close( IN );
	return @lines;
}

sub locate_line {
	# For carets and colons, use the . character to represent them
	
	my ( $start, $find, $lines_ref ) = (@_);
	my ( $index ) = grep { @$lines_ref[$_] =~ /$find/ } $start ..@$lines_ref;
	return $index;
}

sub save_file {
	my ( $cfg, $patch, @lines ) = @_;
	my $old = "$cfg.pre_$patch";
	my $new = "$cfg.new";
	
	open( OUT, ">$new" ) || die "ERROR: Can't write new cfg '$new'!\n";
	print OUT @lines;
	close( OUT );
	
	if( ! rename( $cfg, $old ) ) {
		die "Error number: $!\nERROR: Unable to rename previous config '$cfg' to '$old'!\n";
	}
	
	if( ! rename( $new, $cfg ) ) {
		die "ERROR: Unable to rename new config to '$cfg'!\n";
	}
}
